@@ -15,6 +15,7 @@ Creates Template::Flute::Container object.
 
 =cut
 
+use base 'Template::Flute';
 use Template::Flute::Expression;
 
 our %expression_cache;
@@ -96,14 +97,17 @@ sub visible {
 	if ($key = $self->{sob}->{value}) {
 	    # check whether this is an expression or a simple value
 	    if ($key =~ /^\w[0-9\w_-]*$/) {
-		if (exists $self->{values}) {
-			if ($self->{values}->{$key}) {
-				return 1;
-			}
-			return 0;
-		}
+            # value holds method
+            return $self->{values}->$key
+                if $self->_is_record_object($self->{values}) && $self->{values}->can($key); 
+    		if (exists $self->{values}) {
+    			if ($self->{values}->{$key}) {
+    				return 1;
+    			}
+    			return 0;
+    		}
 
-		return undef;
+    		return undef;
 	    }
 	    else {
             if (! exists $self->{_expr_parser}) {
